addCode abstract method

T addCode(
  1. CodeRun codeRun
)

Creates and registers the appropriate code term for this BDD step.

Each mixing class implements this to return its corresponding code term. Use .code() from a runner import instead of calling this directly. Only runner implementations (including runners in other packages, which import package:bdd_framework/core.dart) should call it.

Implementation

T addCode(CodeRun codeRun);