example method

BddExample example(
  1. val v1, [
  2. val? v2,
  3. val? v3,
  4. val? v4,
  5. val? v5,
  6. val? v6,
  7. val? v7,
  8. val? v8,
  9. val? v9,
  10. val? v10,
  11. val? v11,
  12. val? v12,
  13. val? v13,
  14. val? v14,
  15. val? v15,
])

Adds a single example row to the current BDD and returns the shared BddExample block for continued chaining.

The first value is required so that an example row can never be empty via the public DSL. Remaining values are optional and will be ignored when null.

Implementation

BddExample example(
  val v1, [
  val? v2,
  val? v3,
  val? v4,
  val? v5,
  val? v6,
  val? v7,
  val? v8,
  val? v9,
  val? v10,
  val? v11,
  val? v12,
  val? v13,
  val? v14,
  val? v15,
]) =>
    bdd.addExampleValues([
      v1,
      v2,
      v3,
      v4,
      v5,
      v6,
      v7,
      v8,
      v9,
      v10,
      v11,
      v12,
      v13,
      v14,
      v15,
    ].nonNulls.toList());