BddCodeable<T> mixin
A mixin that enables a _BaseTerm to have executable code blocks attached
to it via runner-specific extensions.
Runner extensions (e.g., BddDartTestCodeable) call addCode which creates
the corresponding internal code term and returns it. The type parameter T
represents the concrete code term type returned (e.g., _GivenCode), allowing
the runner extension to preserve the fluent chain's static type.
- Available extensions
Properties
- bdd → BddFramework
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addCode(
CodeRun codeRun) → T - Creates and registers the appropriate code term for this BDD step.
-
code(
PatrolTestCallback codeRun) → T -
Available on BddCodeable<
Attaches a code block that injects theT> , provided by the PatrolTestCode extensionPatrolIntegrationTesterdirectly into the callback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited