example method
Adds a single example row to the current BDD and returns the shared BddExample block for continued chaining.
The first value is required so that an example row can never be empty via
the public DSL. Remaining values are optional and will be ignored when
null.
Implementation
BddExample example(
val v1, [
val? v2,
val? v3,
val? v4,
val? v5,
val? v6,
val? v7,
val? v8,
val? v9,
val? v10,
val? v11,
val? v12,
val? v13,
val? v14,
val? v15,
]) =>
bdd.addExampleValues([
v1,
v2,
v3,
v4,
v5,
v6,
v7,
v8,
v9,
v10,
v11,
v12,
v13,
v14,
v15,
].nonNulls.toList());