BddRunnable mixin
A marker mixin to indicate that a _BaseTerm can act as a trigger to run
the test.
Classes that mix in BddRunnable become valid targets for runner extensions
(e.g., BddDartTestRunner, BddFlutterTestRunner) to attach a .run()
method. Only terms that represent a valid end-of-chain position in the BDD
fluent API should mix in this mixin — for example, BddThen, BddExample,
and their corresponding code terms like _ThenCode.
BddScenario intentionally does not mix in BddRunnable, since a scenario without steps is not a valid test.
- Available extensions
Properties
- bdd → BddFramework
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
[PatrolTestCallback? testCallback]) → void -
Available on BddRunnable, provided by the PatrolTestRun extension
Executes the BDD scenario as a Patrol integration test. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited